'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var syntaxDecorators = _interopDefault(require('@babel/plugin-syntax-decorators'));
var syntaxDynamicImport = _interopDefault(require('@babel/plugin-syntax-dynamic-import'));
var syntaxTypeScript = _interopDefault(require('@babel/plugin-syntax-typescript'));
var proposalClassProperties = _interopDefault(require('@babel/plugin-proposal-class-properties'));
var proposalDoExpressions = _interopDefault(require('@babel/plugin-proposal-do-expressions'));
var proposalFunctionBind = _interopDefault(require('@babel/plugin-proposal-function-bind'));
var proposalFunctionSent = _interopDefault(require('@babel/plugin-proposal-function-sent'));
var proposalJsonStrings = _interopDefault(require('@babel/plugin-proposal-json-strings'));
var proposalLogicalAssignmentOperators = _interopDefault(require('@babel/plugin-proposal-logical-assignment-operators'));
var proposalNullishCoalescingOperator = _interopDefault(require('@babel/plugin-proposal-nullish-coalescing-operator'));
var proposalOptionalChaining = _interopDefault(require('@babel/plugin-proposal-optional-chaining'));
var proposalPartialApplication = _interopDefault(require('@babel/plugin-proposal-partial-application'));
var proposalPipelineOperator = _interopDefault(require('@babel/plugin-proposal-pipeline-operator'));
var proposalPrivateMethods = _interopDefault(require('@babel/plugin-proposal-private-methods'));
var proposalThrowExpression = _interopDefault(require('@babel/plugin-proposal-throw-expressions'));
var helperPluginUtils = require('@babel/helper-plugin-utils');

var index = helperPluginUtils.declare(function (api, opts) {
    api.assertVersion(7);
    var _a = opts.decoratorsLegacy, decoratorsLegacy = _a === void 0 ? true : _a, _b = opts.isTSX, isTSX = _b === void 0 ? false : _b, _c = opts.pipelineOperator, pipelineOperator = _c === void 0 ? 'minimal' : _c;
    return {
        plugins: [
            [
                syntaxDecorators,
                {
                    legacy: decoratorsLegacy,
                },
            ],
            syntaxDynamicImport,
            [
                syntaxTypeScript,
                {
                    isTSX: isTSX,
                },
            ],
            proposalClassProperties,
            proposalDoExpressions,
            proposalFunctionBind,
            proposalFunctionSent,
            proposalJsonStrings,
            proposalLogicalAssignmentOperators,
            proposalNullishCoalescingOperator,
            proposalOptionalChaining,
            proposalPartialApplication,
            [
                proposalPipelineOperator,
                {
                    proposal: pipelineOperator,
                },
            ],
            proposalPrivateMethods,
            proposalThrowExpression,
        ],
        // no need to override if it has been enabled
        overrides: isTSX
            ? undefined
            : [
                {
                    test: /\.[jt]sx$/,
                    plugins: [
                        [
                            syntaxTypeScript,
                            {
                                isTSX: true,
                            },
                        ],
                    ],
                },
            ],
    };
});

module.exports = index;
